@@ -56,14 +56,14 @@ from renku.core.commands.rerun import rerun_workflows
 def show_inputs(client, workflow):
     """Show workflow inputs and exit."""
     for input_ in workflow.inputs:
-        click.echo("{id}: {default}".format(id=input_._id, default=input_.consumes.path,))
+        click.echo("{id}: {default}".format(id=input_._id, default=input_.consumes.path))
     sys.exit(0)
 
 
 def edit_inputs(client, workflow):
     """Edit workflow inputs."""
     for input_ in workflow.inputs:
-        new_path = click.prompt("{0._id}".format(input_), default=input_.consumes.path,)
+        new_path = click.prompt("{0._id}".format(input_), default=input_.consumes.path)
         input_.consumes.path = str(Path(os.path.abspath(new_path)).relative_to(client.path))
 
         try:
@@ -76,7 +76,7 @@ def edit_inputs(client, workflow):
 
     for step in workflow.subprocesses:
         for argument in step.process.arguments:
-            argument.value = click.prompt("{0._id}".format(argument), default=argument.value,)
+            argument.value = click.prompt("{0._id}".format(argument), default=argument.value)
 
     return workflow
 
@@ -92,10 +92,27 @@ def edit_inputs(client, workflow):
 )
 @option_siblings
 @click.option(
-    "--default-inputs", "inputs", default=True, flag_value=lambda _, workflow: workflow, help="Use default inputs.",
+    "--default-inputs",
+    "inputs",
+    default=True,
+    flag_value=lambda _, workflow: workflow,
+    help="Use default inputs.",
+    type=click.types.UnprocessedParamType(),
+)
+@click.option(
+    "--show-inputs",
+    "inputs",
+    flag_value=show_inputs,
+    help=show_inputs.__doc__,
+    type=click.types.UnprocessedParamType(),
+)
+@click.option(
+    "--edit-inputs",
+    "inputs",
+    flag_value=edit_inputs,
+    help=edit_inputs.__doc__,
+    type=click.types.UnprocessedParamType(),
 )
-@click.option("--show-inputs", "inputs", flag_value=show_inputs, help=show_inputs.__doc__)
-@click.option("--edit-inputs", "inputs", flag_value=edit_inputs, help=edit_inputs.__doc__)
 @click.argument("paths", type=click.Path(exists=True, dir_okay=True), nargs=-1, required=True)
 def rerun(revision, roots, siblings, inputs, paths):
     """Recreate files generated by a sequence of ``run`` commands."""
