@@ -231,9 +231,7 @@ def service(ctx, env):
     show_default=True,
     help="Request silent for more than this many seconds are dropped.",
 )
-@click.option(
-    "-d", "--debug", default=False, is_flag=True, help="Start API in debug mode.",
-)
+@click.option("-d", "--debug", default=False, is_flag=True, help="Start API in debug mode.")
 def api_start(addr, port, timeout, debug):
     """Start service JSON-RPC API in active shell session."""
     run_api(addr, port, timeout, debug)
@@ -261,7 +259,7 @@ def ps(ctx):
     processes = list_renku_processes()
     headers = [{k.upper(): v for k, v in rec.items()} for rec in processes]
 
-    output = tabulate(processes, headers=headers,)
+    output = tabulate(processes, headers=headers)
 
     if not processes:
         click.echo("Renku service components are down.")
@@ -403,7 +401,8 @@ def all_logs(ctx, follow, output_all, errors):
 @service.command(name="apispec")
 def apispec():
     """Return the api spec."""
-    from renku.service.entrypoint import app, get_apispec
+    from renku.service.entrypoint import app
+    from renku.service.views.apispec import get_apispec
 
     with app.test_request_context():
         click.echo(get_apispec(app).to_yaml())
