@@ -16,7 +16,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Serializers for datasets."""
+import textwrap
 
+from renku.core.models.datasets import DatasetDetailsJson
 from renku.core.models.json import dumps
 
 from .tabulate import tabulate
@@ -27,23 +29,38 @@ def tabular(client, datasets, *, columns=None):
     if not columns:
         columns = "id,date_created,name,creators,tags,version"
 
+    _create_dataset_short_description(datasets)
+
     return tabulate(collection=datasets, columns=columns, columns_mapping=DATASETS_COLUMNS)
 
 
+def _create_dataset_short_description(datasets):
+    for dataset in datasets:
+        lines = textwrap.wrap(dataset.description, width=64, max_lines=5) if dataset.description else []
+        dataset.short_description = "\n".join(lines)
+
+
 def jsonld(client, datasets, **kwargs):
     """Format datasets as JSON-LD."""
     data = [dataset.as_jsonld() for dataset in datasets]
     return dumps(data, indent=2)
 
 
+def json(client, datasets, **kwargs):
+    """Format datasets as JSON."""
+    data = [DatasetDetailsJson().dump(dataset) for dataset in datasets]
+    return dumps(data, indent=2)
+
+
 DATASETS_FORMATS = {
     "tabular": tabular,
     "json-ld": jsonld,
+    "json": json,
 }
 """Valid formatting options."""
 
 DATASETS_COLUMNS = {
-    "id": ("uid", "id"),
+    "id": ("identifier", "id"),
     "created": ("date_created", None),
     "date_created": ("date_created", None),
     "short_name": ("name", None),
@@ -54,4 +71,5 @@ DATASETS_COLUMNS = {
     "version": ("version", None),
     "title": ("title", "title"),
     "keywords": ("keywords_csv", "keywords"),
+    "description": ("short_description", "description"),
 }
