@@ -18,6 +18,7 @@
 """Project initialization logic."""
 
 import json
+import re
 import tempfile
 from collections import OrderedDict, namedtuple
 from pathlib import Path
@@ -37,6 +38,7 @@ from renku.core.management.config import RENKU_HOME
 from renku.core.management.repository import INIT_APPEND_FILES, INIT_KEEP_FILES
 from renku.core.models.tabulate import tabulate
 from renku.core.utils import communication
+from renku.version import __version__, is_release
 
 TEMPLATE_MANIFEST = "manifest.yaml"
 
@@ -74,7 +76,7 @@ def create_template_sentence(templates, describe=False, instructions=False):
         for index, template_elem in enumerate(templates)
     ]
 
-    table_headers = OrderedDict((("index", "Index"), ("id", "Id"), ("variables", "Parameters"),))
+    table_headers = OrderedDict((("index", "Index"), ("id", "Id"), ("variables", "Parameters")))
 
     if describe:
         table_headers["description"] = "Description"
@@ -158,14 +160,16 @@ def verify_template_variables(template_data, metadata):
             show_default=False,
         )
         metadata[key] = value
-    useless_variables = input_parameters_keys - template_variables_keys
-    if len(useless_variables) > 0:
+
+    # ignore internal variables, i.e. __\w__
+    internal_keys = re.compile(r"__\w+__$")
+    input_parameters_keys = set([i for i in input_parameters_keys if not internal_keys.match(i)])
+    unused_variables = input_parameters_keys - template_variables_keys
+    if len(unused_variables) > 0:
         communication.info(
             "These parameters are not used by the template and were "
-            "ignored:\n\t{}".format("\n\t".join(useless_variables))
+            "ignored:\n\t{}".format("\n\t".join(unused_variables))
         )
-        for key in useless_variables:
-            del metadata[key]
 
     return metadata
 
@@ -270,6 +274,8 @@ def _init(
     metadata["__sanitized_project_name__"] = ""
     metadata["__repository__"] = ""
     metadata["__project_slug__"] = ""
+    if is_release() and "__renku_version__" not in metadata:
+        metadata["__renku_version__"] = __version__
     metadata["name"] = name
 
     template_path = template_folder / template_data["folder"]
@@ -292,9 +298,7 @@ def _init(
             append_paths = "\n\t".join(append)
             message += f"The following files exist in the directory and will be appended to:\n\t{append_paths}\n"
 
-        communication.confirm(
-            f"{message}Proceed?", abort=True, warning=True,
-        )
+        communication.confirm(f"{message}Proceed?", abort=True, warning=True)
 
     branch_name = create_backup_branch(client, path)
 
@@ -330,7 +334,7 @@ def init_command():
     return Command().command(_init)
 
 
-def fetch_template_from_git(source, ref="master", tempdir=None):
+def fetch_template_from_git(source, ref=None, tempdir=None):
     """Fetch the template from a git repository and checkout the relevant data.
 
     :param source: url or full path of the templates repository
@@ -347,17 +351,22 @@ def fetch_template_from_git(source, ref="master", tempdir=None):
     except git.exc.GitCommandError as e:
         raise errors.GitError("Cannot clone repo from {0}".format(source)) from e
 
-    try:
-        # fetch ref and set the HEAD
-        template_repo.remotes.origin.fetch(ref)
+    if ref:
         try:
-            template_repo.head.reset(template_repo.commit(ref))
-        except git.exc.BadName:
-            ref = "origin/{0}".format(ref)
-            template_repo.head.reset(template_repo.commit(ref))
+            # fetch ref and set the HEAD
+            template_repo.remotes.origin.fetch()
+            try:
+                template_repo.head.reset(template_repo.commit(ref))
+            except git.exc.BadName:
+                ref = "origin/{0}".format(ref)
+                template_repo.head.reset(template_repo.commit(ref))
+            git_repo = git.Git(str(tempdir))
+        except (git.exc.GitCommandError, git.exc.BadName) as e:
+            raise errors.GitError("Cannot fetch and checkout reference {0}".format(ref)) from e
+    else:
+        template_repo.remotes.origin.fetch()
+        template_repo.head.reset(template_repo.commit())
         git_repo = git.Git(str(tempdir))
-    except git.exc.GitCommandError as e:
-        raise errors.GitError("Cannot fetch and checkout reference {0}".format(ref)) from e
 
     # checkout the manifest
     try:
@@ -376,7 +385,7 @@ def fetch_template(template_source, template_ref):
     :return: tuple of (template manifest, template folder, template source, template version)
     """
     if template_source and template_source != "renku":
-        communication.echo("Fetching template from {0}@{1}... ".format(template_source, template_ref))
+        communication.echo("Fetching template from {0}@{1}... ".format(template_source, template_ref or ""))
         template_folder = Path(mkdtemp())
         _, template_version = fetch_template_from_git(template_source, template_ref, template_folder)
         template_manifest = read_template_manifest(template_folder, checkout=True)
@@ -384,6 +393,9 @@ def fetch_template(template_source, template_ref):
     else:
         from renku import __version__
 
+        if template_ref:
+            raise errors.ParameterError("Templates included in renku don't support specifying a template_ref")
+
         template_folder = Path(pkg_resources.resource_filename("renku", "templates"))
         template_manifest = read_template_manifest(template_folder)
         template_source = "renku"
@@ -525,7 +537,7 @@ def _create_from_template_local(
 
     metadata = {**default_metadata, **metadata}
 
-    client.init_repository(False, None, initial_branch=initial_branch)
+    client.init_repository(False, user, initial_branch=initial_branch)
 
     create_from_template(
         template_path=template_path,
