@@ -43,6 +43,7 @@ DATAVERSE_API_PATH = "api/v1"
 
 DATAVERSE_VERSION_API = "info/version"
 DATAVERSE_METADATA_API = "datasets/export"
+DATAVERSE_VERSIONS_API = "datasets/:persistentId/versions"
 DATAVERSE_FILE_API = "access/datafile/:persistentId/"
 DATAVERSE_EXPORTER = "schema.org"
 
@@ -119,6 +120,15 @@ def make_records_url(record_id, base_url):
     return urllib.parse.urlunparse(url_parts)
 
 
+def make_versions_url(record_id, base_url):
+    """Create URL to access the versions of a record."""
+    url_parts = list(urlparse.urlparse(base_url))
+    url_parts[2] = pathlib.posixpath.join(DATAVERSE_API_PATH, DATAVERSE_VERSIONS_API)
+    args_dict = {"exporter": DATAVERSE_EXPORTER, "persistentId": record_id}
+    url_parts[4] = urllib.parse.urlencode(args_dict)
+    return urllib.parse.urlunparse(url_parts)
+
+
 def make_file_url(file_id, base_url):
     """Create URL to access record by ID."""
     url_parts = list(urlparse.urlparse(base_url))
@@ -150,6 +160,24 @@ class DataverseProvider(ProviderApi):
 
         return is_dataverse_uri or is_dataverse_doi
 
+    @staticmethod
+    def supports_export():
+        """Whether this provider supports dataset export."""
+        return True
+
+    @staticmethod
+    def supports_import():
+        """Whether this provider supports dataset import."""
+        return True
+
+    @staticmethod
+    def export_parameters():
+        """Returns parameters that can be set for export."""
+        return {
+            "dataverse-server": ("Dataverse server URL.", str),
+            "dataverse-name": ("Dataverse name to export to.", str),
+        }
+
     @staticmethod
     def record_id(uri):
         """Extract record id from uri."""
@@ -164,7 +192,7 @@ class DataverseProvider(ProviderApi):
                 raise LookupError("record not found. Status: {}".format(response.status_code))
             return response
 
-    def find_record(self, uri, client=None):
+    def find_record(self, uri, client=None, **kwargs):
         """Retrieves a record from Dataverse.
 
         :raises: ``LookupError``
@@ -197,22 +225,22 @@ class DataverseProvider(ProviderApi):
             dataset=dataset, access_token=access_token, server_url=self._server_url, dataverse_name=self._dataverse_name
         )
 
-    def set_parameters(self, client, *, dataverse_server_url, dataverse_name, **kwargs):
+    def set_parameters(self, client, *, dataverse_server, dataverse_name, **kwargs):
         """Set and validate required parameters for a provider."""
         CONFIG_BASE_URL = "server_url"
 
-        if not dataverse_server_url:
-            dataverse_server_url = client.get_value("dataverse", CONFIG_BASE_URL)
+        if not dataverse_server:
+            dataverse_server = client.get_value("dataverse", CONFIG_BASE_URL)
         else:
-            client.set_value("dataverse", CONFIG_BASE_URL, dataverse_server_url, global_only=True)
+            client.set_value("dataverse", CONFIG_BASE_URL, dataverse_server, global_only=True)
 
-        if not dataverse_server_url:
+        if not dataverse_server:
             raise errors.ParameterError("Dataverse server URL is required.")
 
         if not dataverse_name:
             raise errors.ParameterError("Dataverse name is required.")
 
-        self._server_url = dataverse_server_url
+        self._server_url = dataverse_server
         self._dataverse_name = dataverse_name
 
 
@@ -247,6 +275,19 @@ class DataverseRecordSerializer:
             file_list.append(mapped_file)
         return file_list
 
+    @property
+    def version(self):
+        """Get the major and minor version of this dataset."""
+        uri = make_versions_url(DataverseProvider.record_id(self._uri), self._uri)
+        response = self._dataverse._make_request(uri).json()
+        newest_version = response["data"][0]
+        return "{}.{}".format(newest_version["versionNumber"], newest_version["versionMinorNumber"])
+
+    @property
+    def latest_uri(self):
+        """Get uri of latest version."""
+        return self._uri
+
     def get_files(self):
         """Get Dataverse files metadata as ``DataverseFileSerializer``."""
         if not self.files:
@@ -259,6 +300,8 @@ class DataverseRecordSerializer:
         files = self.get_files()
         dataset = Dataset.from_jsonld(self._json, client=client, schema_class=_DataverseDatasetSchema)
 
+        dataset.version = self.version
+
         if dataset.description and not dataset.description.strip():
             dataset.description = None
 
