@@ -253,6 +253,15 @@ class ZenodoRecordSerializer:
         """Get record metadata as jsonld."""
         response = self._zenodo.accept_jsonld().make_request(self._uri)
         self._jsonld = response.json()
+
+        if "image" in self._jsonld and isinstance(self._jsonld["image"], str):
+            self._jsonld["image"] = {
+                "@id": self._jsonld["image"],
+                "@type": "ImageObject",
+                "position": 1,
+                "contentUrl": self._jsonld["image"],
+            }
+
         return self._jsonld
 
     def get_files(self):
@@ -362,7 +371,7 @@ class ZenodoDeposition:
         file = {"file": open(str(filepath), "rb")}
 
         response = requests.post(
-            url=self.upload_file_url, params=self.exporter.default_params, data=request_payload, files=file,
+            url=self.upload_file_url, params=self.exporter.default_params, data=request_payload, files=file
         )
         check_or_raise(response)
 
@@ -457,7 +466,7 @@ class ZenodoExporter(ExporterApi):
         # Step 3. Upload all files to created deposition
         with tqdm(total=len(self.dataset.files)) as progressbar:
             for file_ in self.dataset.files:
-                deposition.upload_file(file_.full_path,)
+                deposition.upload_file(file_.full_path)
                 progressbar.update(1)
 
         # Step 4. Publish newly created deposition
