@@ -25,8 +25,10 @@ import click
 
 from renku.core import errors
 from renku.core.incubation.command import Command
+from renku.core.incubation.graph import unique_workflow
 from renku.core.management.git import get_mapped_std_streams
 from renku.core.models.cwl.command_line_tool import CommandLineToolFactory
+from renku.core.models.provenance.provenance_graph import ProvenanceGraph
 from renku.core.utils import communication
 from renku.core.utils.urls import get_slug
 
@@ -55,6 +57,12 @@ def _run_command(
         if name != valid_name:
             raise errors.ParameterError(f"Invalid name: '{name}' (Hint: '{valid_name}' is valid).")
 
+        # TODO: refactor this once we switch to Database
+        if client.provenance_graph_path.exists():
+            workflows = unique_workflow(ProvenanceGraph.from_json(client.provenance_graph_path))
+            if name in workflows:
+                raise errors.ParameterError(f"Duplicate workflow name: workflow '{name}' already exists.")
+
     paths = explicit_outputs if no_output_detection else client.candidate_paths
     mapped_std = get_mapped_std_streams(paths, streams=("stdout", "stderr"))
 
@@ -131,7 +139,7 @@ def _run_command(
                     sys.stderr = old_stderr
 
             return_code = call(
-                factory.command_line, cwd=os.getcwd(), **{key: getattr(sys, key) for key in mapped_std.keys()},
+                factory.command_line, cwd=os.getcwd(), **{key: getattr(sys, key) for key in mapped_std.keys()}
             )
 
             sys.stdout.flush()
@@ -147,9 +155,7 @@ def _run_command(
             if return_code not in (success_codes or {0}):
                 raise errors.InvalidSuccessCode(return_code, success_codes=success_codes)
 
-        client.process_and_store_run(
-            command_line_tool=tool, name=name, description=description, keywords=keyword, client=client
-        )
+        client.process_and_store_run(command_line_tool=tool, name=name, description=description, keywords=keyword)
 
         if factory.messages:
             communication.echo(factory.messages)
