@@ -78,9 +78,7 @@ def _migrate_submodule_based_datasets(client):
 
     for remote_client in remote_clients.values():
         if not is_project_unsupported(remote_client):
-            migrate(
-                remote_client, skip_template_update=True, skip_docker_update=True,
-            )
+            migrate(remote_client, skip_template_update=True, skip_docker_update=True)
 
     metadata = {}
 
