@@ -94,9 +94,7 @@ def _migrate_old_workflows(client):
 
             committer = Actor("renku {0}".format(__version__), version_url)
 
-            client.repo.index.commit(
-                commit_msg, committer=committer, skip_hooks=True,
-            )
+            client.repo.index.commit(commit_msg, committer=committer, skip_hooks=True)
 
 
 def _migrate_cwl(client, path, commit):
@@ -287,7 +285,7 @@ def _migrate_single_step(client, cmd_line_tool, path, commit=None, parent_commit
     if not persist:
         return run, None
 
-    step_name = "{0}_{1}.yaml".format(uuid.uuid4().hex, secure_filename("_".join(cmd_line_tool.baseCommand)),)
+    step_name = "{0}_{1}.yaml".format(uuid.uuid4().hex, secure_filename("_".join(cmd_line_tool.baseCommand)))
 
     absolute_path = client.workflow_path / step_name
     path = absolute_path.relative_to(client.path)
@@ -355,7 +353,7 @@ def _entity_from_path(client, path, commit):
     if str(path).startswith(os.path.join(client.renku_home, client.DATASETS)):
         return Dataset.from_yaml(path=client.path / path, client=client, commit=commit)
     else:
-        return entity_cls(commit=commit, client=client, path=str(path),)
+        return entity_cls(commit=commit, client=client, path=str(path))
 
 
 def _invalidations_from_commit(client, commit):
@@ -377,7 +375,7 @@ def _invalidations_from_commit(client, commit):
 
 def _get_activity_entity(client, commit, path, collections, deleted=False):
     """Gets the entity associated with this Activity and path."""
-    client, commit, path = client.resolve_in_submodules(commit, path,)
+    client, commit, path = client.resolve_in_submodules(commit, path)
     output_path = client.path / path
     parents = list(output_path.relative_to(client.path).parents)
 
@@ -387,7 +385,7 @@ def _get_activity_entity(client, commit, path, collections, deleted=False):
         if str(parent) in collections:
             collection = collections[str(parent)]
         else:
-            collection = Collection(client=client, commit=commit, path=str(parent), members=[], parent=collection,)
+            collection = Collection(client=client, commit=commit, path=str(parent), members=[], parent=collection)
             members.append(collection)
             collections[str(parent)] = collection
 
@@ -400,7 +398,7 @@ def _get_activity_entity(client, commit, path, collections, deleted=False):
     if str(path).startswith(os.path.join(client.renku_home, client.DATASETS)) and not deleted:
         entity = Dataset.from_yaml(path=client.path / path, client=client, commit=commit)
     else:
-        entity = entity_cls(commit=commit, client=client, path=str(path), parent=collection,)
+        entity = entity_cls(commit=commit, client=client, path=str(path), parent=collection)
 
     if collection:
         collection.members.append(entity)
