@@ -32,9 +32,15 @@ class JobSchema(Schema):
 
     job_id = fields.String(missing=lambda: uuid.uuid4().hex)
     user_id = fields.String(required=True)
+    project_id = fields.String()
+    renku_op = fields.String()
 
     state = fields.String(required=False, missing=USER_JOB_STATE_ENQUEUED)
     extras = fields.Dict(required=False)
+    client_extras = fields.String(required=False, missing=None)
+
+    ctrl_result = fields.Dict(required=False)
+    ctrl_context = fields.Dict(required=False)
 
     @post_load
     def make_job(self, data, **options):
