@@ -17,27 +17,28 @@
 # limitations under the License.
 """Renku service datasets edit controller."""
 from renku.core.commands.dataset import edit_dataset
+from renku.service.cache.models.job import Job
 from renku.service.config import CACHE_UPLOADS_PATH
 from renku.service.controllers.api.abstract import ServiceCtrl
-from renku.service.controllers.api.mixins import ReadWithSyncOperation
+from renku.service.controllers.api.mixins import RenkuOpSyncMixin
 from renku.service.serializers.datasets import DatasetEditRequest, DatasetEditResponseRPC
 from renku.service.views import result_response
 
 
-class DatasetsEditCtrl(ServiceCtrl, ReadWithSyncOperation):
+class DatasetsEditCtrl(ServiceCtrl, RenkuOpSyncMixin):
     """Controller for datasets edit endpoint."""
 
     REQUEST_SERIALIZER = DatasetEditRequest()
     RESPONSE_SERIALIZER = DatasetEditResponseRPC()
 
-    def __init__(self, cache, user_data, request_data):
+    def __init__(self, cache, user_data, request_data, migrate_project=False):
         """Construct a datasets edit list controller."""
         self.ctx = DatasetsEditCtrl.REQUEST_SERIALIZER.load(request_data)
 
         if self.ctx.get("commit_message") is None:
             self.ctx["commit_message"] = "service: dataset edit {0}".format(self.ctx["name"])
 
-        super(DatasetsEditCtrl, self).__init__(cache, user_data, request_data)
+        super(DatasetsEditCtrl, self).__init__(cache, user_data, request_data, migrate_project=migrate_project)
 
     @property
     def context(self):
@@ -69,8 +70,11 @@ class DatasetsEditCtrl(ServiceCtrl, ReadWithSyncOperation):
     def to_response(self):
         """Execute controller flow and serialize to service response."""
         op_result, remote_branch = self.execute_and_sync()
-        edited, warnings = op_result
 
+        if isinstance(op_result, Job):
+            return result_response(DatasetsEditCtrl.JOB_RESPONSE_SERIALIZER, op_result)
+
+        edited, warnings = op_result
         response = {
             "edited": edited,
             "warnings": warnings,
