@@ -29,12 +29,30 @@ DATASETS_JOB_QUEUE = "datasets.jobs"
 MIGRATIONS_JOB_QUEUE = "project.migrations"
 GRAPH_JOB_QUEUE = "graph.jobs"
 
+DELAYED_CTRL_DATASETS_CREATE = "delayed.ctrl.DatasetsCreateCtrl"
+DELAYED_CTRL_DATASETS_ADD = "delayed.ctrl.DatasetsAddFileCtrl"
+DELAYED_CTRL_DATASETS_REMOVE = "delayed.ctrl.DatasetsRemoveCtrl"
+DELAYED_CTRL_DATASETS_IMPORT = "delayed.ctrl.DatasetsImportCtrl"
+DELAYED_CTRL_DATASETS_EDIT = "delayed.ctrl.DatasetsEditCtrl"
+DELAYED_CTRL_DATASETS_UNLINK = "delayed.ctrl.DatasetsUnlinkCtrl"
+DELAYED_CTRL_PROJECT_MIGRATE = "delayed.ctrl.MigrateProjectCtrl"
+DELAYED_CTRL_CONFIG_SET = "delayed.ctrl.SetConfigCtrl"
+
+
 QUEUES = [
     CLEANUP_QUEUE_FILES,
     CLEANUP_QUEUE_PROJECTS,
     DATASETS_JOB_QUEUE,
     MIGRATIONS_JOB_QUEUE,
     GRAPH_JOB_QUEUE,
+    DELAYED_CTRL_DATASETS_CREATE,
+    DELAYED_CTRL_DATASETS_ADD,
+    DELAYED_CTRL_DATASETS_REMOVE,
+    DELAYED_CTRL_DATASETS_IMPORT,
+    DELAYED_CTRL_DATASETS_EDIT,
+    DELAYED_CTRL_DATASETS_UNLINK,
+    DELAYED_CTRL_PROJECT_MIGRATE,
+    DELAYED_CTRL_CONFIG_SET,
 ]
 
 
