@@ -21,6 +21,7 @@ import uuid
 from datetime import datetime
 from urllib.parse import urlparse
 
+import yagup
 from marshmallow import Schema, ValidationError, fields, post_load, pre_load, validates
 from werkzeug.utils import secure_filename
 
@@ -98,15 +99,29 @@ class FileListResponseRPC(JsonRPCResponse):
     result = fields.Nested(FileListResponse)
 
 
-class ProjectCloneRequest(Schema):
-    """Request schema for project clone."""
+class RepositoryCloneRequest(Schema):
+    """Request schema for repository clone."""
 
     git_url = fields.String(required=True)
     depth = fields.Integer(missing=PROJECT_CLONE_DEPTH_DEFAULT)
     ref = fields.String(missing=None)
 
 
-class ProjectCloneContext(ProjectCloneRequest):
+class RepositoryCloneContext(RepositoryCloneRequest):
+    """Context schema for a git repository clone."""
+
+    @validates("git_url")
+    def validate_git_url(self, value):
+        """Validates git url."""
+        try:
+            yagup.parse(value)
+        except yagup.exceptions.InvalidURL as e:
+            raise ValidationError("Invalid `git_url`") from e
+
+        return value
+
+
+class ProjectCloneContext(RepositoryCloneContext):
     """Context schema for project clone."""
 
     project_id = fields.String(missing=lambda: uuid.uuid4().hex)
@@ -120,16 +135,6 @@ class ProjectCloneContext(ProjectCloneRequest):
     owner = fields.String()
     token = fields.String()
 
-    @validates("git_url")
-    def validate_git_url(self, value):
-        """Validates git url."""
-        try:
-            GitURL.parse(value)
-        except UnicodeError as e:
-            raise ValidationError("`git_url` contains unsupported characters") from e
-        except ConfigurationError as e:
-            raise ValidationError("Invalid `git_url`") from e
-
     @pre_load()
     def set_owner_name(self, data, **kwargs):
         """Set owner and name fields."""
