@@ -17,18 +17,28 @@
 # limitations under the License.
 """Version information for Renku."""
 
-__version__ = '0.15.0'
+import re
+
+__version__ = "0.16.1"
+
+
+def is_release():
+    """Check if current version is a release semver."""
+    if re.match(r"\d+.\d+.\d+$", __version__):
+        return True
+    return False
 
 
 def _get_distribution_url():
     try:
         import pkg_resources
-        d = pkg_resources.get_distribution('renku')
+
+        d = pkg_resources.get_distribution("renku")
         metadata = d._get_metadata(d.PKG_INFO)
-        home_page = [m for m in metadata if m.startswith('Home-page:')]
-        return home_page[0].split(':', 1)[1].strip()
+        home_page = [m for m in metadata if m.startswith("Home-page:")]
+        return home_page[0].split(":", 1)[1].strip()
     except Exception:
-        return 'N/A'
+        return "N/A"
 
 
-version_url = '{}/tree/{}'.format(_get_distribution_url(), 'v' + __version__)
+version_url = "{}/tree/{}".format(_get_distribution_url(), "v" + __version__)
