@@ -489,7 +489,7 @@ def test_add_unicode_file(tmpdir, runner, project, client):
     new_file.write(str("test"))
 
     # add data
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)],)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)])
     assert 0 == result.exit_code
 
     result = runner.invoke(cli, ["log", "--format", "json-ld", "--strict", f"data/my-dataset/{filename}"])
@@ -514,7 +514,7 @@ def test_multiple_file_to_dataset(tmpdir, runner, project, client):
         paths.append(str(new_file))
 
     # add data
-    result = runner.invoke(cli, ["dataset", "add", "dataset"] + paths, catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "dataset"] + paths, catch_exceptions=False)
     assert 0 == result.exit_code
 
 
@@ -533,7 +533,7 @@ def test_repository_file_to_dataset(runner, client_with_new_graph, subdirectory,
 
     # add data
     command = ["graph"] if use_graph else []
-    result = runner.invoke(cli, command + ["dataset", "add", "dataset", str(a_path)], catch_exceptions=False,)
+    result = runner.invoke(cli, command + ["dataset", "add", "dataset", str(a_path)], catch_exceptions=False)
     assert 0 == result.exit_code
 
     with client.with_dataset("dataset") as dataset:
@@ -565,7 +565,7 @@ def test_relative_import_to_dataset(tmpdir, runner, client, subdirectory):
 
     paths = [str(zero_data), str(first_level), str(second_level)]
 
-    result = runner.invoke(cli, ["dataset", "add", "dataset"] + paths, catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "dataset"] + paths, catch_exceptions=False)
     assert 0 == result.exit_code
 
     assert os.stat(client.path / DATA_DIR / "dataset" / "zero.txt")
@@ -582,14 +582,14 @@ def test_relative_import_to_dataset(tmpdir, runner, client, subdirectory):
 )
 def test_usage_error_in_add_from_url(runner, client, params, message):
     """Test user's errors when adding URL/local file to a dataset."""
-    result = runner.invoke(cli, ["dataset", "add", "remote", "--create"] + params, catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "remote", "--create"] + params, catch_exceptions=False)
     assert 2 == result.exit_code
     assert message in result.output
 
 
 def test_add_from_local_repo_warning(runner, client, data_repository, directory_tree):
     """Test a warning is printed when adding from a local git repo."""
-    result = runner.invoke(cli, ["dataset", "add", "dataset", "--create", str(directory_tree)], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "dataset", "--create", str(directory_tree)], catch_exceptions=False)
     assert 0 == result.exit_code
     assert "Use remote's Git URL instead to enable lineage " in result.output
 
@@ -599,7 +599,7 @@ def test_add_data_directory(runner, client):
     result = runner.invoke(cli, ["dataset", "create", "new-dataset"])
     assert 0 == result.exit_code
 
-    result = runner.invoke(cli, ["dataset", "add", "new-dataset", "data/new-dataset"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "new-dataset", "data/new-dataset"], catch_exceptions=False)
     assert 2 == result.exit_code
     assert "Cannot add dataset's data directory recursively" in result.output
 
@@ -623,7 +623,7 @@ def test_dataset_add_with_copy(tmpdir, runner, project, client):
         paths.append(str(new_file))
 
     # add data
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths)
     assert 0 == result.exit_code
 
     received_inodes = []
@@ -655,7 +655,7 @@ def test_dataset_add_many(tmpdir, runner, project, client):
         paths.append(str(new_file))
 
     # add data
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths)
     assert 0 == result.exit_code
 
     assert len(client.repo.head.commit.message) <= 100
@@ -663,7 +663,7 @@ def test_dataset_add_many(tmpdir, runner, project, client):
 
 def test_dataset_file_path_from_subdirectory(runner, client, subdirectory):
     """Test adding a file into a dataset and check path independent
-    of the CWD """
+    of the CWD"""
     # create a dataset
     result = runner.invoke(cli, ["dataset", "create", "dataset"])
     assert 0 == result.exit_code
@@ -676,7 +676,7 @@ def test_dataset_file_path_from_subdirectory(runner, client, subdirectory):
     client.repo.git.commit(message="Added file a")
 
     # add data
-    result = runner.invoke(cli, ["dataset", "add", "dataset", str(a_path)], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "dataset", str(a_path)], catch_exceptions=False)
     assert 0 == result.exit_code
 
     with client.with_dataset("dataset") as dataset:
@@ -729,7 +729,7 @@ def test_datasets_ls_files_lfs(tmpdir, large_file, runner, project):
     paths.append(str(large_file))
 
     # NOTE: add data to dataset
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths, catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths, catch_exceptions=False)
     assert 0 == result.exit_code
 
     # NOTE: check files
@@ -763,7 +763,7 @@ def test_datasets_ls_files_json(tmpdir, large_file, runner, project):
     paths.append(str(large_file))
 
     # NOTE: add data to dataset
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths, catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths, catch_exceptions=False)
     assert 0 == result.exit_code
 
     # NOTE: check files
@@ -896,7 +896,7 @@ def test_datasets_ls_files_with_name(directory_tree, runner, project):
     assert 0 == result.exit_code
 
     # add data to dataset
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(directory_tree)], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(directory_tree)], catch_exceptions=False)
     assert 0 == result.exit_code
 
     # list files with name
@@ -1140,19 +1140,19 @@ def test_dataset_tag(tmpdir, runner, project, client, subdirectory):
     new_file.write(str("test"))
 
     # add data to dataset
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False)
     assert 0 == result.exit_code
 
     # tag dataset
-    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "1.0"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "1.0"], catch_exceptions=False)
     assert 0 == result.exit_code
 
     result = runner.invoke(
-        cli, ["dataset", "tag", "my-dataset", "A", "-d", "short descriptiön"], catch_exceptions=False,
+        cli, ["dataset", "tag", "my-dataset", "A", "-d", "short descriptiön"], catch_exceptions=False
     )
     assert 0 == result.exit_code
 
-    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "aBc9.34-11_55.t"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "aBc9.34-11_55.t"], catch_exceptions=False)
     assert 0 == result.exit_code
 
 
@@ -1167,22 +1167,22 @@ def test_dataset_ls_tags(tmpdir, runner, project, client, form):
     new_file.write(str("test"))
 
     # add data to dataset
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False)
     assert 0 == result.exit_code
 
     commit1 = client.repo.head.commit.hexsha
 
     # tag dataset
-    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "1.0", "-d", "first tag!"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "1.0", "-d", "first tag!"], catch_exceptions=False)
     assert 0 == result.exit_code
 
     commit2 = client.repo.head.commit.hexsha
 
-    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "aBc9.34-11_55.t"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "aBc9.34-11_55.t"], catch_exceptions=False)
     assert 0 == result.exit_code
 
     result = runner.invoke(
-        cli, ["dataset", "ls-tags", "my-dataset", "--format={}".format(form)], catch_exceptions=False,
+        cli, ["dataset", "ls-tags", "my-dataset", "--format={}".format(form)], catch_exceptions=False
     )
     assert 0 == result.exit_code
     assert "1.0" in result.output
@@ -1202,29 +1202,29 @@ def test_dataset_rm_tag(tmpdir, runner, project, client, subdirectory):
     new_file.write(str("test"))
 
     # add data to dataset
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False)
     assert 0 == result.exit_code
 
     commit1 = client.repo.head.commit.hexsha
 
     # tag dataset
-    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "1.0", "-d", "first tag!"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "tag", "my-dataset", "1.0", "-d", "first tag!"], catch_exceptions=False)
     assert 0 == result.exit_code
 
-    result = runner.invoke(cli, ["dataset", "ls-tags", "my-dataset"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "ls-tags", "my-dataset"], catch_exceptions=False)
     assert 0 == result.exit_code
     assert "1.0" in result.output
     assert "first tag!" in result.output
     assert commit1 in result.output
 
-    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "2.0"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "2.0"], catch_exceptions=False)
     assert 2 == result.exit_code
     assert "not found" in result.output
 
-    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1.0"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1.0"], catch_exceptions=False)
     assert 0 == result.exit_code
 
-    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1.0"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1.0"], catch_exceptions=False)
     assert 2 == result.exit_code
     assert "not found" in result.output
 
@@ -1239,15 +1239,15 @@ def test_dataset_rm_tags_multiple(tmpdir, runner, project, client):
     new_file.write(str("test"))
 
     # add data to dataset
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False)
     assert 0 == result.exit_code
 
     for i in range(1, 4):
         # tag dataset
-        result = runner.invoke(cli, ["dataset", "tag", "my-dataset", str(i)], catch_exceptions=False,)
+        result = runner.invoke(cli, ["dataset", "tag", "my-dataset", str(i)], catch_exceptions=False)
         assert 0 == result.exit_code
 
-    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1", "2", "3"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1", "2", "3"], catch_exceptions=False)
     assert 0 == result.exit_code
     assert "1" not in result.output
     assert "2" not in result.output
@@ -1255,7 +1255,7 @@ def test_dataset_rm_tags_multiple(tmpdir, runner, project, client):
 
 
 def test_dataset_rm_tags_failure(tmpdir, runner, project, client):
-    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1"], catch_exceptions=False)
 
     assert 1 == result.exit_code
     result = runner.invoke(cli, ["dataset", "create", "my-dataset"])
@@ -1267,10 +1267,10 @@ def test_dataset_rm_tags_failure(tmpdir, runner, project, client):
     new_file.write(str("test"))
 
     # add data to dataset
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset", str(new_file)], catch_exceptions=False)
     assert 0 == result.exit_code
 
-    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1"], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "rm-tags", "my-dataset", "1"], catch_exceptions=False)
     assert 2 == result.exit_code
 
 
@@ -1278,7 +1278,7 @@ def test_dataset_clean_up_when_add_fails(runner, client, subdirectory):
     """Test project is cleaned when dataset add fails for a new dataset."""
     # add a non-existing path to a new dataset
     result = runner.invoke(
-        cli, ["dataset", "add", "--create", "new-dataset", "non-existing-file"], catch_exceptions=True,
+        cli, ["dataset", "add", "--create", "new-dataset", "non-existing-file"], catch_exceptions=True
     )
 
     assert 2 == result.exit_code
@@ -1413,6 +1413,7 @@ def test_lfs_hook_autocommit(runner, client, subdirectory, large_file):
     assert "You are trying to commit large files to Git instead of Git-LFS" in result[2]
     assert "Adding files to LFS" in result[2]
     assert 'Tracking "large-file"' in result[2]
+    assert len(client.dirty_paths) == 0  # NOTE: make sure repo is clean
 
 
 def test_lfs_hook_autocommit_env(runner, client, subdirectory, large_file):
@@ -1432,6 +1433,7 @@ def test_lfs_hook_autocommit_env(runner, client, subdirectory, large_file):
     assert "You are trying to commit large files to Git instead of Git-LFS" in result[2]
     assert "Adding files to LFS" in result[2]
     assert 'Tracking "large-file"' in result[2]
+    assert len(client.dirty_paths) == 0  # NOTE: make sure repo is clean
 
 
 def test_lfs_hook_can_be_avoided(runner, project, subdirectory, large_file):
@@ -1674,7 +1676,7 @@ def test_workflow_with_external_file(runner, client, directory_tree, run, subdir
     result = runner.invoke(cli, ["status"])
     assert 1 == result.exit_code
 
-    assert 0 == run(args=("update", "--all",))
+    assert 0 == run(args=("update", "--all"))
     result = runner.invoke(cli, ["status"])
     assert 0 == result.exit_code
 
@@ -1828,7 +1830,7 @@ def test_datasets_provenance_after_create(runner, client_with_new_graph, use_gra
     ]
     if use_graph:
         args = ["graph"] + args
-    assert 0 == runner.invoke(cli, args,).exit_code
+    assert 0 == runner.invoke(cli, args).exit_code
 
     dataset = next(client_with_new_graph.datasets_provenance.get_by_name("my-data"))
 
