@@ -31,7 +31,7 @@ def test_dataset_add(tmpdir, runner, client, subdirectory):
     ignored_file.write("My Specification")
 
     # The file should be ignored and command fail
-    result = runner.invoke(cli, ["dataset", "add", "testing", ignored_file.strpath], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "testing", ignored_file.strpath], catch_exceptions=False)
 
     assert 1 == result.exit_code
 
