@@ -137,7 +137,7 @@ def test_dataset_import_real_param(doi, runner, project, sleep_after, client):
 
 
 @pytest.mark.parametrize(
-    "doi", [("10.5281/zenodo.3239984", "n"), ("zenodo.org/record/3239986", "n"), ("10.5281/zenodo.3239982", "n"),]
+    "doi", [("10.5281/zenodo.3239984", "n"), ("zenodo.org/record/3239986", "n"), ("10.5281/zenodo.3239982", "n")]
 )
 @pytest.mark.integration
 @flaky(max_runs=10, min_passes=1)
@@ -172,7 +172,7 @@ def test_dataset_import_real_doi_warnings(runner, project, sleep_after):
 
     result = runner.invoke(cli, ["dataset", "ls"])
     assert 0 == result.exit_code, result.output + str(result.stderr_bytes)
-    assert "pyndl_naive_discr_v0.7.2" in result.output
+    assert "pyndl_naive_discr_v0.8.1" in result.output
 
 
 @pytest.mark.parametrize(
@@ -182,7 +182,7 @@ def test_dataset_import_real_doi_warnings(runner, project, sleep_after):
         ("10.7910/DVN/S8MSVFXXXX", "provider DVN not found"),
         ("10.5281/zenodo.1494915", "no files have been found"),
         ("https://zenodo.org/record/2621201248", "record not found"),
-        ("https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/F4NUMRXXXX", "record not found",),
+        ("https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/F4NUMRXXXX", "record not found"),
     ],
 )
 @pytest.mark.integration
@@ -199,6 +199,7 @@ def test_dataset_import_expected_err(runner, project, doi, err):
     [
         "https://zenodo.org/record/2621208",
         "https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/F4NUMR",
+        "https://zenodo.org/record/830044",
     ],
 )
 @pytest.mark.integration
@@ -380,7 +381,7 @@ def test_import_renku_dataset_preserves_directory_hierarchy(runner, project, cli
 
 @pytest.mark.integration
 @flaky(max_runs=10, min_passes=1)
-@pytest.mark.parametrize("url", ["https://dev.renku.ch/datasets/e3e1beba-0559-4fdd-8e46-82963cec9fe2",])
+@pytest.mark.parametrize("url", ["https://dev.renku.ch/datasets/e3e1beba-0559-4fdd-8e46-82963cec9fe2"])
 def test_dataset_import_renku_fail(runner, client, monkeypatch, url):
     """Test dataset import fails if cannot clone repo."""
     from renku.core.management import LocalClient
@@ -399,7 +400,7 @@ def test_dataset_import_renku_fail(runner, client, monkeypatch, url):
 
 @pytest.mark.integration
 @flaky(max_runs=10, min_passes=1)
-@pytest.mark.parametrize("url", ["https://dev.renku.ch/datasets/e3e1beba-0559-4fdd-8e46-82963cec9fe2",])
+@pytest.mark.parametrize("url", ["https://dev.renku.ch/datasets/e3e1beba-0559-4fdd-8e46-82963cec9fe2"])
 def test_dataset_import_renku_missing_project(runner, client, missing_kg_project_responses, url):
     """Test dataset import fails if cannot find project in KG."""
     result = runner.invoke(cli, ["dataset", "import", url], input="y")
@@ -613,7 +614,7 @@ def test_dataset_export_upload_multiple(
         paths.append(str(new_file))
 
     # add data
-    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths, catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "my-dataset"] + paths, catch_exceptions=False)
     assert 0 == result.exit_code, result.output + str(result.stderr_bytes)
 
     with client.with_dataset("my-dataset") as dataset:
@@ -712,7 +713,7 @@ def test_export_dataset_wrong_provider(runner, project, tmpdir, client):
 
     result = runner.invoke(cli, ["dataset", "export", "my-dataset", "unsupported-provider"])
     assert 2 == result.exit_code, result.output + str(result.stderr_bytes)
-    assert "invalid choice: unsupported-provider. (choose from " in result.output
+    assert "Invalid value" in result.output
 
 
 @pytest.mark.integration
@@ -873,13 +874,13 @@ def test_add_data_from_git_with_wildcards(runner, client, params, files):
     remote = "https://github.com/SwissDataScienceCenter/renku-jupyter.git"
 
     result = runner.invoke(
-        cli, ["dataset", "add", "remote", "--create", "--ref", "0.5.2", remote] + params, catch_exceptions=False,
+        cli, ["dataset", "add", "remote", "--create", "--ref", "0.5.2", remote] + params, catch_exceptions=False
     )
     assert 0 == result.exit_code
     assert files == set(os.listdir("data/remote"))
 
     result = runner.invoke(
-        cli, ["dataset", "add", "remote", "--ref", "0.5.2", "-d", "new", remote] + params, catch_exceptions=False,
+        cli, ["dataset", "add", "remote", "--ref", "0.5.2", "-d", "new", remote] + params, catch_exceptions=False
     )
     assert 0 == result.exit_code
     assert files == set(os.listdir("data/remote/new"))
@@ -938,7 +939,7 @@ def test_usage_error_in_add_from_git(runner, client, params, n_urls, message):
 
     urls = n_urls * [remote]
 
-    result = runner.invoke(cli, ["dataset", "add", "remote", "--ref", "0.3.0"] + params + urls, catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "remote", "--ref", "0.3.0"] + params + urls, catch_exceptions=False)
     assert 2 == result.exit_code, result.output + str(result.stderr_bytes)
     assert message in result.output
 
@@ -1450,7 +1451,7 @@ def test_check_disk_space(runner, client, monkeypatch, url):
 
     monkeypatch.setattr(shutil, "disk_usage", disk_usage)
 
-    result = runner.invoke(cli, ["dataset", "add", "-c", "my-data", url], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "-c", "my-data", url], catch_exceptions=False)
     assert 1 == result.exit_code, result.output + str(result.stderr_bytes)
     assert "Insufficient disk space" in result.output
 
@@ -1493,7 +1494,7 @@ def test_migration_submodule_datasets(isolated_runner, old_repository_with_submo
 @flaky(max_runs=10, min_passes=1)
 def test_dataset_add_dropbox(runner, client, project, url, size):
     """Test importing data from dropbox."""
-    result = runner.invoke(cli, ["dataset", "add", "-c", "my-dropbox-data", url], catch_exceptions=False,)
+    result = runner.invoke(cli, ["dataset", "add", "-c", "my-dropbox-data", url], catch_exceptions=False)
     assert 0 == result.exit_code
 
     filename = Path(parse.urlparse(url).path).name
