@@ -25,7 +25,7 @@ from renku.core.errors import RenkuImportError
 
 def test_dataverse_exporter_init():
     """Check construction of a dataverse exporter."""
-    exporter = DataverseExporter(dataset="my-dataset", access_token="let-me-in",)
+    exporter = DataverseExporter(dataset="my-dataset", access_token="let-me-in")
 
     assert exporter
     assert "my-dataset" == exporter.dataset
@@ -34,7 +34,7 @@ def test_dataverse_exporter_init():
 
 def test_dataverse_deposition_init():
     """Check construction of dataverse deposition."""
-    deposit = _DataverseDeposition(access_token="let-me-in", server_url="http://sss",)
+    deposit = _DataverseDeposition(access_token="let-me-in", server_url="http://sss")
 
     assert deposit
     assert "let-me-in" == deposit.access_token
