@@ -23,6 +23,8 @@ import uuid
 
 import pytest
 
+from tests.utils import modified_environ
+
 
 def test_service_cache_ensure_user(svc_client_cache):
     """Test service cache user creation."""
@@ -114,10 +116,10 @@ def test_service_cache_get_jobs(svc_client_cache):
     user2 = cache.ensure_user({"user_id": "testuser2"})
 
     for _ in range(10):
-        job = cache.make_job(user, {"job_id": uuid.uuid4().hex,})
+        job = cache.make_job(user, {"job_id": uuid.uuid4().hex})
         assert job
 
-    job2 = cache.make_job(user2, {"job_id": uuid.uuid4().hex,})
+    job2 = cache.make_job(user2, {"job_id": uuid.uuid4().hex})
     assert job2
 
     retrieved_jobs = cache.get_jobs(user)
@@ -253,7 +255,7 @@ def test_service_cache_make_project(svc_client_cache):
         "name": "renku-project-template",
         "depth": 1,
         "git_url": "https://github.com/SwissDataScienceCenter/renku-project-template",
-        "email": "contact@justsam.io",
+        "email": "contact@renkulab.io",
         "fullname": "renku the frog",
         "token": "None",
         "owner": "SwissDataScienceCenter",
@@ -263,7 +265,7 @@ def test_service_cache_make_project(svc_client_cache):
     assert project.age == 1
     assert not project.ttl_expired()
 
-    os.environ["RENKU_SVC_CLEANUP_TTL_PROJECTS"] = "1"
-    time.sleep(1)
-    assert project.age == 2
-    assert project.ttl_expired()
+    with modified_environ(RENKU_SVC_CLEANUP_TTL_PROJECTS="1"):
+        time.sleep(1)
+        assert project.age == 2
+        assert project.ttl_expired()
