@@ -17,16 +17,17 @@
 # limitations under the License.
 """Renku service templates read manifest controller tests."""
 import pytest
-from git import GitCommandError
 from marshmallow import ValidationError
 
+from renku.core.errors import GitError
+
 
 def test_template_read_manifest_ctrl(ctrl_init, svc_client_with_templates, mocker):
     """Test template read manifest controller."""
     from renku.service.controllers.templates_read_manifest import TemplatesReadManifestCtrl
 
     cache, user_data = ctrl_init
-    svc_client, headers, template_params = svc_client_with_templates
+    _, _, template_params = svc_client_with_templates
 
     ctrl = TemplatesReadManifestCtrl(cache, user_data, template_params)
     ctrl_mock = mocker.patch.object(
@@ -37,13 +38,13 @@ def test_template_read_manifest_ctrl(ctrl_init, svc_client_with_templates, mocke
     assert {"result": {"templates": ctrl_mock.return_value}} == response.json
 
 
-@pytest.mark.parametrize("git_url", ["https://github.com", "https://github.com/SwissDataScienceCenter",])
+@pytest.mark.parametrize("git_url", ["https://github.com/`test", "https://github.com/SwissDataScienceCenter/}"])
 def test_validation_exc_template_read_manifest_ctrl(git_url, ctrl_init, svc_client_with_templates, mocker):
     """Test validation exception on template read manifest controller."""
     from renku.service.controllers.templates_read_manifest import TemplatesReadManifestCtrl
 
     cache, user_data = ctrl_init
-    svc_client, headers, template_params = svc_client_with_templates
+    _, _, template_params = svc_client_with_templates
     template_params["url"] = git_url
 
     with pytest.raises(ValidationError):
@@ -58,10 +59,10 @@ def test_found_exc_template_read_manifest_ctrl(git_url, ctrl_init, svc_client_wi
     from renku.service.controllers.templates_read_manifest import TemplatesReadManifestCtrl
 
     cache, user_data = ctrl_init
-    svc_client, headers, template_params = svc_client_with_templates
+    _, _, template_params = svc_client_with_templates
     template_params["url"] = git_url
 
     ctrl = TemplatesReadManifestCtrl(cache, user_data, template_params)
 
-    with pytest.raises(GitCommandError):
+    with pytest.raises(GitError):
         ctrl.to_response()
