@@ -62,7 +62,7 @@ def test_list_upload_files_all_no_auth(svc_client):
         "Content-Type": "application/json",
         "accept": "application/json",
     }
-    response = svc_client.get("/cache.files_list", headers=headers,)
+    response = svc_client.get("/cache.files_list", headers=headers)
 
     assert 200 == response.status_code
 
@@ -77,7 +77,7 @@ def test_file_upload(svc_client, identity_headers):
     headers.pop("Content-Type")
 
     response = svc_client.post(
-        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), uuid.uuid4().hex),), headers=headers,
+        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), uuid.uuid4().hex)), headers=headers
     )
 
     assert response
@@ -96,7 +96,7 @@ def test_file_upload_override(svc_client, identity_headers):
     filename = uuid.uuid4().hex
 
     response = svc_client.post(
-        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename),), headers=headers,
+        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename)), headers=headers
     )
 
     assert response
@@ -106,7 +106,7 @@ def test_file_upload_override(svc_client, identity_headers):
     old_file_id = response.json["result"]["files"][0]["file_id"]
 
     response = svc_client.post(
-        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename),), headers=headers,
+        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename)), headers=headers
     )
 
     assert response
@@ -118,7 +118,7 @@ def test_file_upload_override(svc_client, identity_headers):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(b"this is a test"), filename),),
+        data=dict(file=(io.BytesIO(b"this is a test"), filename)),
         query_string={"override_existing": True},
         headers=headers,
     )
@@ -140,7 +140,7 @@ def test_file_upload_same_file(svc_client, identity_headers):
     filename = uuid.uuid4().hex
 
     response = svc_client.post(
-        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename),), headers=headers,
+        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename)), headers=headers
     )
 
     assert response
@@ -151,7 +151,7 @@ def test_file_upload_same_file(svc_client, identity_headers):
     assert isinstance(uuid.UUID(response.json["result"]["files"][0]["file_id"]), uuid.UUID)
 
     response = svc_client.post(
-        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename),), headers=headers,
+        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename)), headers=headers
     )
 
     assert response
@@ -164,7 +164,7 @@ def test_file_upload_same_file(svc_client, identity_headers):
 @pytest.mark.service
 def test_file_upload_no_auth(svc_client):
     """Check failed file upload."""
-    response = svc_client.post("/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), "datafile.txt"),),)
+    response = svc_client.post("/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), "datafile.txt")))
 
     assert response
     assert 200 == response.status_code
@@ -198,7 +198,7 @@ def test_file_upload_with_users(svc_client, identity_headers):
     }
 
     response = svc_client.post(
-        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename),), headers=headers_user1
+        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename)), headers=headers_user1
     )
 
     assert {"result"} == set(response.json.keys())
@@ -208,7 +208,7 @@ def test_file_upload_with_users(svc_client, identity_headers):
     assert 200 == response.status_code
 
     response = svc_client.post(
-        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename),), headers=headers_user2
+        "/cache.files_upload", data=dict(file=(io.BytesIO(b"this is a test"), filename)), headers=headers_user2
     )
 
     assert response
@@ -355,7 +355,7 @@ def test_clone_projects_invalid_headers(svc_client, identity_headers, it_remote_
         "git_url": it_remote_repo_url,
     }
 
-    response = svc_client.post("/cache.project_clone", data=json.dumps(payload), headers=identity_headers,)
+    response = svc_client.post("/cache.project_clone", data=json.dumps(payload), headers=identity_headers)
     assert response
 
     assert {"result"} == set(response.json.keys())
@@ -384,8 +384,8 @@ def test_upload_zip_unpack_archive(datapack_zip, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_zip.read_bytes()), datapack_zip.name),),
-        query_string={"unpack_archive": True, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_zip.read_bytes()), datapack_zip.name)),
+        query_string={"unpack_archive": True, "override_existing": True},
         headers=headers,
     )
 
@@ -409,8 +409,8 @@ def test_upload_zip_archive(datapack_zip, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_zip.read_bytes()), datapack_zip.name),),
-        query_string={"unpack_archive": False, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_zip.read_bytes()), datapack_zip.name)),
+        query_string={"unpack_archive": False, "override_existing": True},
         headers=headers,
     )
 
@@ -434,8 +434,8 @@ def test_upload_tar_unpack_archive(datapack_tar, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_tar.read_bytes()), datapack_tar.name),),
-        query_string={"unpack_archive": True, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_tar.read_bytes()), datapack_tar.name)),
+        query_string={"unpack_archive": True, "override_existing": True},
         headers=headers,
     )
 
@@ -449,7 +449,7 @@ def test_upload_tar_unpack_archive(datapack_tar, svc_client_with_repo):
         assert not file_["is_archive"]
         assert not file_["unpack_archive"]
 
-    response = svc_client.get("/cache.files_list", headers=headers,)
+    response = svc_client.get("/cache.files_list", headers=headers)
 
     assert response
     assert 200 == response.status_code
@@ -475,8 +475,8 @@ def test_upload_tar_archive(datapack_tar, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_tar.read_bytes()), datapack_tar.name),),
-        query_string={"unpack_archive": False, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_tar.read_bytes()), datapack_tar.name)),
+        query_string={"unpack_archive": False, "override_existing": True},
         headers=headers,
     )
 
@@ -500,8 +500,8 @@ def test_upload_gz_unpack_archive(datapack_gz, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_gz.read_bytes()), datapack_gz.name, "application/x-gzip"),),
-        query_string={"unpack_archive": True, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_gz.read_bytes()), datapack_gz.name, "application/x-gzip")),
+        query_string={"unpack_archive": True, "override_existing": True},
         headers=headers,
     )
 
@@ -515,7 +515,7 @@ def test_upload_gz_unpack_archive(datapack_gz, svc_client_with_repo):
         assert not file_["is_archive"]
         assert not file_["unpack_archive"]
 
-    response = svc_client.get("/cache.files_list", headers=headers,)
+    response = svc_client.get("/cache.files_list", headers=headers)
 
     assert response
     assert 200 == response.status_code
@@ -541,8 +541,8 @@ def test_upload_gz_archive(datapack_gz, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_gz.read_bytes()), datapack_gz.name, "application/x-gzip"),),
-        query_string={"unpack_archive": False, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_gz.read_bytes()), datapack_gz.name, "application/x-gzip")),
+        query_string={"unpack_archive": False, "override_existing": True},
         headers=headers,
     )
 
@@ -566,8 +566,8 @@ def test_field_upload_resp_fields(datapack_tar, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_tar.read_bytes()), datapack_tar.name),),
-        query_string={"unpack_archive": True, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_tar.read_bytes()), datapack_tar.name)),
+        query_string={"unpack_archive": True, "override_existing": True},
         headers=headers,
     )
 
@@ -761,7 +761,7 @@ def test_cache_gets_synchronized(local_remote_repository, directory_tree, quick_
         "project_id": project_id,
     }
 
-    response = svc_client.get("/datasets.list", query_string=params, headers=identity_headers,)
+    response = svc_client.get("/datasets.list", query_string=params, headers=identity_headers)
     assert response
     assert 200 == response.status_code
 
@@ -773,7 +773,7 @@ def test_cache_gets_synchronized(local_remote_repository, directory_tree, quick_
         "name": uuid.uuid4().hex,
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=identity_headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=identity_headers)
 
     assert response
     assert 200 == response.status_code
