@@ -42,7 +42,7 @@ def assert_rpc_response(response, with_key="result"):
     """Check rpc result in response."""
     assert response and 200 == response.status_code
 
-    response_text = re.sub(r"http\S+", "", json.dumps(response.json),)
+    response_text = re.sub(r"http\S+", "", json.dumps(response.json))
     assert with_key in response_text
 
 
@@ -58,7 +58,7 @@ def test_create_dataset_view(svc_client_with_repo):
         "name": uuid.uuid4().hex,
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
     assert response
     assert_rpc_response(response)
 
@@ -78,7 +78,7 @@ def test_remote_create_dataset_view(svc_client_cache, it_remote_repo_url):
         "name": "{0}".format(uuid.uuid4().hex),
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
     assert response
     assert_rpc_response(response, with_key="error")
     assert {"code", "migration_required", "reason"} == set(response.json["error"].keys())
@@ -97,7 +97,7 @@ def test_delay_create_dataset_view(svc_client_cache, it_remote_repo_url):
         "is_delayed": True,
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response, with_key="result")
@@ -116,7 +116,7 @@ def test_create_dataset_wrong_ref_view(svc_client_with_repo):
         "name": uuid.uuid4().hex,
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert {
@@ -135,9 +135,7 @@ def test_remove_dataset_view(svc_client_with_repo):
         "name": uuid.uuid4().hex,
     }
 
-    svc_client.post(
-        "/datasets.create", data=json.dumps(payload), headers=headers,
-    )
+    svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     response = svc_client.post("/datasets.remove", data=json.dumps(payload), headers=headers)
 
@@ -184,7 +182,7 @@ def test_create_dataset_with_metadata(svc_client_with_repo):
         "keywords": ["keyword1", "keyword2"],
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -195,7 +193,7 @@ def test_create_dataset_with_metadata(svc_client_with_repo):
     params = {
         "project_id": project_id,
     }
-    response = svc_client.get("/datasets.list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -228,7 +226,7 @@ def test_create_dataset_with_images(svc_client_with_repo):
         ],
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert {"error"} == response.json.keys()
@@ -245,7 +243,7 @@ def test_create_dataset_with_images(svc_client_with_repo):
         ],
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -256,7 +254,7 @@ def test_create_dataset_with_images(svc_client_with_repo):
     params = {
         "project_id": project_id,
     }
-    response = svc_client.get("/datasets.list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -293,10 +291,10 @@ def test_create_dataset_with_image_download(svc_client_with_repo, img_url):
         "title": "my little dataset",
         "creators": [{"name": "name123", "email": "name123@ethz.ch", "affiliation": "ethz"}],
         "description": "my little description",
-        "images": [{"content_url": "https://renkulab.io/api/doesnt_exist.png", "position": 1, "mirror_locally": True},],
+        "images": [{"content_url": "https://renkulab.io/api/doesnt_exist.png", "position": 1, "mirror_locally": True}],
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
     assert response
     assert {"error"} == response.json.keys()
 
@@ -306,10 +304,10 @@ def test_create_dataset_with_image_download(svc_client_with_repo, img_url):
         "title": "my little dataset",
         "creators": [{"name": "name123", "email": "name123@ethz.ch", "affiliation": "ethz"}],
         "description": "my little description",
-        "images": [{"content_url": img_url, "position": 1, "mirror_locally": True,},],
+        "images": [{"content_url": img_url, "position": 1, "mirror_locally": True}],
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -320,7 +318,7 @@ def test_create_dataset_with_image_download(svc_client_with_repo, img_url):
     params = {
         "project_id": project_id,
     }
-    response = svc_client.get("/datasets.list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -344,7 +342,7 @@ def test_create_dataset_with_uploaded_images(svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(b"this is a test"), "image1.jpg"),),
+        data=dict(file=(io.BytesIO(b"this is a test"), "image1.jpg")),
         query_string={"override_existing": True},
         headers=headers,
     )
@@ -360,7 +358,7 @@ def test_create_dataset_with_uploaded_images(svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(b"this is another test"), "image2.png"),),
+        data=dict(file=(io.BytesIO(b"this is another test"), "image2.png")),
         query_string={"override_existing": True},
         headers=headers,
     )
@@ -382,10 +380,10 @@ def test_create_dataset_with_uploaded_images(svc_client_with_repo):
         "title": "my little dataset",
         "creators": [{"name": "name123", "email": "name123@ethz.ch", "affiliation": "ethz"}],
         "description": "my little description",
-        "images": [{"file_id": file_id1, "position": 1}, {"file_id": file_id2, "position": 2},],
+        "images": [{"file_id": file_id1, "position": 1}, {"file_id": file_id2, "position": 2}],
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -396,7 +394,7 @@ def test_create_dataset_with_uploaded_images(svc_client_with_repo):
     params = {
         "project_id": project_id,
     }
-    response = svc_client.get("/datasets.list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -432,7 +430,7 @@ def test_create_dataset_invalid_creator(svc_client_with_repo):
         "description": "my little description",
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert INVALID_PARAMS_ERROR_CODE == response.json["error"]["code"]
@@ -450,7 +448,7 @@ def test_create_dataset_commit_msg(svc_client_with_repo):
 
     payload = {"project_id": project_id, "name": uuid.uuid4().hex, "commit_message": "my awesome dataset"}
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -471,11 +469,11 @@ def test_create_dataset_view_dataset_exists(svc_client_with_repo):
         "name": "mydataset",
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
     assert response
     assert "result" in response.json.keys()
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
     assert response
     assert_rpc_response(response, with_key="error")
 
@@ -492,7 +490,7 @@ def test_create_dataset_view_unknown_param(svc_client_with_repo):
 
     payload = {"project_id": project_id, "name": "mydata", "remote_name": "origin"}
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response, with_key="error")
@@ -569,7 +567,7 @@ def test_add_file_view(svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(b"this is a test"), "datafile1.txt"),),
+        data=dict(file=(io.BytesIO(b"this is a test"), "datafile1.txt")),
         query_string={"override_existing": True},
         headers=headers,
     )
@@ -591,7 +589,7 @@ def test_add_file_view(svc_client_with_repo):
     }
     headers["Content-Type"] = content_type
 
-    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -612,7 +610,7 @@ def test_add_file_commit_msg(svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(b"this is a test"), "datafile1.txt"),),
+        data=dict(file=(io.BytesIO(b"this is a test"), "datafile1.txt")),
         query_string={"override_existing": True},
         headers=headers,
     )
@@ -625,10 +623,10 @@ def test_add_file_commit_msg(svc_client_with_repo):
         "project_id": project_id,
         "name": uuid.uuid4().hex,
         "create_dataset": True,
-        "files": [{"file_id": file_id,},],
+        "files": [{"file_id": file_id}],
     }
     headers["Content-Type"] = content_type
-    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -667,7 +665,7 @@ def test_add_file_failure(svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(b"this is a test"), "datafile1.txt"),),
+        data=dict(file=(io.BytesIO(b"this is a test"), "datafile1.txt")),
         query_string={"override_existing": True},
         headers=headers,
     )
@@ -683,7 +681,7 @@ def test_add_file_failure(svc_client_with_repo):
         "files": [{"file_id": file_id}, {"file_path": "my problem right here"}],
     }
     headers["Content-Type"] = content_type
-    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response, with_key="error")
@@ -703,7 +701,7 @@ def test_list_datasets_view(svc_client_with_repo):
         "project_id": project_id,
     }
 
-    response = svc_client.get("/datasets.list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -755,7 +753,7 @@ def test_list_datasets_anonymous(svc_client_with_repo, it_remote_repo_url):
     assert expected_reason == response.json["error"]["reason"]
 
     params = {
-        "git_url": "https://dev.renku.ch/gitlab/contact/no-renku",
+        "git_url": "https://dev.renku.ch/gitlab/renku-python-integration-tests/no-renku",
     }
 
     response = svc_client.get("/datasets.list", query_string=params, headers={})
@@ -773,7 +771,7 @@ def test_list_datasets_view_remote(svc_client_with_repo, it_remote_repo_url):
 
     params = dict(git_url=it_remote_repo_url)
 
-    response = svc_client.get("/datasets.list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -805,7 +803,7 @@ def test_list_datasets_view_no_auth(svc_client_with_repo):
         "project_id": project_id,
     }
 
-    response = svc_client.get("/datasets.list", query_string=params,)
+    response = svc_client.get("/datasets.list", query_string=params)
 
     assert response
     assert_rpc_response(response, with_key="error")
@@ -836,7 +834,7 @@ def test_list_dataset_files_anonymous(svc_client_with_repo, it_remote_repo_url):
     expected_reason = "Repository could not be accessed - Do you have access rights?"
     assert expected_reason == response.json["error"]["reason"]
 
-    params = {"git_url": "https://dev.renku.ch/gitlab/contact/no-renku", "name": "mydata"}
+    params = {"git_url": "https://dev.renku.ch/gitlab/renku-python-integration-tests/no-renku", "name": "mydata"}
 
     response = svc_client.get("/datasets.files_list", query_string=params, headers={})
     assert_rpc_response(response)
@@ -854,7 +852,7 @@ def test_list_datasets_files_remote(svc_client_with_repo, it_remote_repo_url):
 
     params = dict(git_url=it_remote_repo_url, name="ds1")
 
-    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -872,7 +870,7 @@ def test_remote_create_view(svc_client, it_remote_repo_url, identity_headers):
     """Test creating a delayed dataset create."""
     response = svc_client.post(
         "/datasets.create",
-        data=json.dumps(dict(git_url=it_remote_repo_url, is_delayed=True, name=uuid.uuid4().hex,)),
+        data=json.dumps(dict(git_url=it_remote_repo_url, is_delayed=True, name=uuid.uuid4().hex)),
         headers=identity_headers,
     )
 
@@ -893,7 +891,7 @@ def test_create_and_list_datasets_view(svc_client_with_repo):
         "name": uuid.uuid4().hex,
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
     assert response
 
     assert_rpc_response(response)
@@ -904,7 +902,7 @@ def test_create_and_list_datasets_view(svc_client_with_repo):
         "project_id": project_id,
     }
 
-    response = svc_client.get("/datasets.list", query_string=params_list, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params_list, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -936,7 +934,7 @@ def test_list_dataset_files(svc_client_with_repo):
     file_name = uuid.uuid4().hex
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(b"this is a test"), file_name),),
+        data=dict(file=(io.BytesIO(b"this is a test"), file_name)),
         query_string={"override_existing": True},
         headers=headers,
     )
@@ -952,11 +950,11 @@ def test_list_dataset_files(svc_client_with_repo):
     payload = {
         "project_id": project_id,
         "name": "mydata",
-        "files": [{"file_id": file_id},],
+        "files": [{"file_id": file_id}],
     }
     headers["Content-Type"] = content_type
 
-    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -969,7 +967,7 @@ def test_list_dataset_files(svc_client_with_repo):
         "name": "mydata",
     }
 
-    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers)
     assert response
 
     assert_rpc_response(response)
@@ -990,8 +988,8 @@ def test_add_with_unpacked_archive(datapack_zip, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_zip.read_bytes()), datapack_zip.name),),
-        query_string={"unpack_archive": True, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_zip.read_bytes()), datapack_zip.name)),
+        query_string={"unpack_archive": True, "override_existing": True},
         headers=headers,
     )
 
@@ -1017,7 +1015,7 @@ def test_add_with_unpacked_archive(datapack_zip, svc_client_with_repo):
     }
 
     headers["Content-Type"] = content_type
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1025,9 +1023,9 @@ def test_add_with_unpacked_archive(datapack_zip, svc_client_with_repo):
     assert {"name", "remote_branch"} == set(response.json["result"].keys())
     assert payload["name"] == response.json["result"]["name"]
 
-    payload = {"project_id": project_id, "name": payload["name"], "files": [{"file_id": file_["file_id"]},]}
+    payload = {"project_id": project_id, "name": payload["name"], "files": [{"file_id": file_["file_id"]}]}
 
-    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1040,7 +1038,7 @@ def test_add_with_unpacked_archive(datapack_zip, svc_client_with_repo):
         "name": payload["name"],
     }
 
-    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1061,8 +1059,8 @@ def test_add_with_unpacked_archive_all(datapack_zip, svc_client_with_repo):
 
     response = svc_client.post(
         "/cache.files_upload",
-        data=dict(file=(io.BytesIO(datapack_zip.read_bytes()), datapack_zip.name),),
-        query_string={"unpack_archive": True, "override_existing": True,},
+        data=dict(file=(io.BytesIO(datapack_zip.read_bytes()), datapack_zip.name)),
+        query_string={"unpack_archive": True, "override_existing": True},
         headers=headers,
     )
 
@@ -1091,7 +1089,7 @@ def test_add_with_unpacked_archive_all(datapack_zip, svc_client_with_repo):
     }
 
     headers["Content-Type"] = content_type
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1105,7 +1103,7 @@ def test_add_with_unpacked_archive_all(datapack_zip, svc_client_with_repo):
         "files": files,
     }
 
-    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1118,7 +1116,7 @@ def test_add_with_unpacked_archive_all(datapack_zip, svc_client_with_repo):
         "name": payload["name"],
     }
 
-    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1140,7 +1138,7 @@ def test_add_existing_file(svc_client_with_repo):
         "name": uuid.uuid4().hex,
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
     assert response
     assert_rpc_response(response)
 
@@ -1154,7 +1152,7 @@ def test_add_existing_file(svc_client_with_repo):
         "files": files,
     }
 
-    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1207,7 +1205,7 @@ def test_cached_import_dataset_job(doi, svc_client_cache, project):
     )
 
     assert_rpc_response(response)
-    assert {"created_at", "job_id",} == set(response.json["result"])
+    assert {"created_at", "job_id"} == set(response.json["result"])
 
     user_job = cache.get_job(user, response.json["result"]["job_id"])
     assert response.json["result"]["job_id"] == user_job.job_id
@@ -1219,9 +1217,7 @@ def test_cached_import_dataset_job(doi, svc_client_cache, project):
     assert user_job.job_id in [job["job_id"] for job in response.json["result"]["jobs"]]
 
 
-@pytest.mark.parametrize(
-    "doi", ["10.5281/zenodo.3239980",],
-)
+@pytest.mark.parametrize("doi", ["10.5281/zenodo.3239980"])
 @pytest.mark.integration
 @pytest.mark.service
 @flaky(max_runs=30, min_passes=1)
@@ -1229,7 +1225,7 @@ def test_remote_import_dataset_job(doi, svc_client, it_remote_repo_url, identity
     """Test creating a delayed import of a dataset."""
     response = svc_client.post(
         "/datasets.import",
-        data=json.dumps(dict(git_url=it_remote_repo_url, dataset_uri=doi, is_delayed=True,)),
+        data=json.dumps(dict(git_url=it_remote_repo_url, dataset_uri=doi, is_delayed=True)),
         headers=identity_headers,
     )
 
@@ -1257,7 +1253,7 @@ def test_dataset_add_remote(url, svc_client_cache, project_metadata):
         shutil.copytree(project, dest)
 
     payload = make_dataset_add_payload(project_meta["project_id"], [url])
-    response = client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert_rpc_response(response)
     assert {"files", "name", "project_id", "remote_branch"} == set(response.json["result"])
@@ -1293,7 +1289,7 @@ def test_dataset_add_multiple_remote(svc_client_cache, project_metadata):
         shutil.copytree(project, dest)
 
     payload = make_dataset_add_payload(project_meta["project_id"], [url_gist, url_dbox])
-    response = client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert_rpc_response(response)
     assert {"files", "name", "project_id", "remote_branch"} == set(response.json["result"])
@@ -1319,9 +1315,9 @@ def test_add_remote_and_local_file(svc_client_with_repo):
     svc_client, headers, project_id, _ = svc_client_with_repo
 
     payload = make_dataset_add_payload(
-        project_id, [("file_path", "README.md"), "https://gist.github.com/jsam/d957f306ed0fe4ff018e902df6a1c8e3"],
+        project_id, [("file_path", "README.md"), "https://gist.github.com/jsam/d957f306ed0fe4ff018e902df6a1c8e3"]
     )
-    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.add", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1348,7 +1344,7 @@ def test_edit_datasets_view(svc_client_with_repo):
         "name": name,
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1360,7 +1356,7 @@ def test_edit_datasets_view(svc_client_with_repo):
         "project_id": project_id,
     }
 
-    response = svc_client.get("/datasets.list", query_string=params_list, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params_list, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1402,7 +1398,7 @@ def test_edit_datasets_view_without_modification(svc_client_with_repo):
         "keywords": ["keywords"],
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1414,7 +1410,7 @@ def test_edit_datasets_view_without_modification(svc_client_with_repo):
         "project_id": project_id,
     }
 
-    response = svc_client.get("/datasets.list", query_string=params_list, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params_list, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1435,7 +1431,7 @@ def test_edit_datasets_view_without_modification(svc_client_with_repo):
         "project_id": project_id,
     }
 
-    response = svc_client.get("/datasets.list", query_string=params_list, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params_list, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1469,7 +1465,7 @@ def test_edit_dataset_with_images(svc_client_with_repo):
         ],
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1480,7 +1476,7 @@ def test_edit_dataset_with_images(svc_client_with_repo):
     params = {
         "project_id": project_id,
     }
-    response = svc_client.get("/datasets.list", query_string=params, headers=headers,)
+    response = svc_client.get("/datasets.list", query_string=params, headers=headers)
 
     assert response
     assert_rpc_response(response)
@@ -1589,7 +1585,7 @@ def test_protected_branch(svc_protected_repo):
         "name": uuid.uuid4().hex,
     }
 
-    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers,)
+    response = svc_client.post("/datasets.create", data=json.dumps(payload), headers=headers)
 
     assert_rpc_response(response)
     assert {"result"} == set(response.json.keys())
@@ -1634,7 +1630,7 @@ def test_unlink_file_no_filter_error(unlink_file_setup):
     svc_client, headers, unlink_payload = unlink_file_setup
     unlink_payload.pop("include_filters")
 
-    response = svc_client.post("/datasets.unlink", data=json.dumps(unlink_payload), headers=headers,)
+    response = svc_client.post("/datasets.unlink", data=json.dumps(unlink_payload), headers=headers)
 
     expected_reason = "Validation error: `schema` - one of the filters must be specified"
     assert {"error": {"code": -32602, "reason": expected_reason}} == response.json
@@ -1648,7 +1644,7 @@ def test_unlink_file_exclude(unlink_file_setup):
     svc_client, headers, unlink_payload = unlink_file_setup
     unlink_payload["exclude_filters"] = unlink_payload.pop("include_filters")
 
-    response = svc_client.post("/datasets.unlink", data=json.dumps(unlink_payload), headers=headers,)
+    response = svc_client.post("/datasets.unlink", data=json.dumps(unlink_payload), headers=headers)
 
     assert {
         "error": {"code": RENKU_EXCEPTION_ERROR_CODE, "reason": "Invalid parameter value - No records found."}
